@@ -23,7 +23,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '0.80';
+our $VERSION = '0.801';
 #Used to turn on and off newline checking.  Some techniques can skip over newlines, and some can't.
 
 # Preloaded methods go here.
@@ -52,195 +52,19 @@ sub setordered
 sub new {
   my %dat;
 
-my $poop = q{
-{
-use Tie::Hash::Indexed;
-use Data::Dumper;
-my  $withoutnewline = qr{([\t\r ]*|(\/[*].*?[*]\/))*};
-my  $withnewline =qr{(\s*|(\/[*].*?[*]\/)|((#|;|\/\/).*?\n))*}sm;
-
-sub array2hash
- {
- my $hashref=shift;
- my %hashed; 
- my $parser = shift;
- if($parser->{'ordered'}) { 
- tie(%hashed, "Tie::Hash::Indexed");
- };
- my @unhashed=@{$hashref};
-  for my $elem (@unhashed)
-  {
-   if(ref $elem eq 'ARRAY')
-   {
-   if(scalar(@{$elem})==2)
-   {
-    if(exists($hashed{$$elem[0]})) 
-    {
-       if(ref($hashed{$$elem[0]})=~/ARRAY/) {
-        my @temparry=@{$hashed{$$elem[0]}};
-        if(!($temparry[$#temparry]=~/loQuaTistop/)) { push(@{$hashed{$$elem[0]}},$$elem[1]); }
-	else { 
-	      delete($temparry[$#temparry]); 
-	      $hashed{$$elem[0]}=[\@temparry,$$elem[1]];
-	     }
-       }
-       else { $hashed{$$elem[0]} = [$hashed{$$elem[0]},$$elem[1]]; }
-    } 
-    else {
-    	$hashed{$$elem[0]}=$$elem[1]; 
-         if(ref($hashed{$$elem[0]})=~/ARRAY/) {
-	     push @{$hashed{$$elem[0]}},'loQuaTistop'; }
-	   #Add this as a marker to show that nothing has yet been added to the array.
-         } 
-   } 
-   else { $hashed{$$elem[0]}={} if(!exists($hashed{$$elem[0]})); };
-  };
-  };
-   for my $key (%hashed) {
-    if(ref($hashed{$key})=~/ARRAY/)
-    {
-    delete($hashed{$key}[scalar(@{$hashed{$key}})-1]) if($hashed{$key}[scalar(@{$hashed{$key}})-1]=~/loQuaTistop/); 
-    };
-   };
-  return \%hashed;
- };
-
-sub section_checker 
- { return [shift,array2hash(shift,shift)]; };
-}
-
-#Variable names must be followed by newline or end tokens.
-#Lookahead assertion takes care of this I hope.
-#They must also NOT start with certain things.
-varname: /[^\s]+?(?=[\n\{\}\[\]\(\)=:<>]|\/>|<\/)/ {
-     #Eliminate trailing spaces
-     $item[1]=~s/([^\s])\s*$/$1/;
-     undef;
-     $item[1] if(length($item[1])>0);
-     }
-
-svar: /\'(.+?)\'/sm {$1;}
-    | /\"(.+?)"/sm {$1;}
-    | /([^\{\}\[\]\(\)=:<>\/\\,#;\s]+)/  {
-    $1; #Old pattern: (?=[\n\{\}\[\]\(\)=:<>\s]|\/>|<\/|$)
-    #New pattern is more strict.  No reserved characters allowed at all, and no spaces.
-    }
-
-single: /\s*(.*?)(?=[\n\{\}\[\]\(\)=:<>\s]|\/>|<\/|$)/  
-{ $1 if(length($1)>0); #This has been deprecated (too slow). Only using svar now.
-}
-
-
-#Ini files are the only kind of section that can't contain more ini files.
-#That's why they're in their own spot. 
-#No other type may contain inis, or there would be ambiguity
-start: section(s)  { array2hash($item[1],$thisparser);}
-#I'm going backwards - section refers to sections.  This has the potential to 
-#generate infinite recursion, but in this case it will not.
-section:   '<' svar <commit> xml_1[$item[2]]  {[$item[2],$item[4]]}
-       | ini_name <commit> strict_assign(s?) {section_checker($item[1],$item[3],$thisparser)}
-       | varlist bracket_section {my $title = $item[1]; 
-                                  $title = join(' ',@{$item[1]}) if(ref $item[1] eq 'ARRAY');
-                                  section_checker($title,$item[2],$thisparser); 
-				 }
-       | assign 
-
-bracket_section: '(' section(s?) ')' {$item[2]}
-               | '{' section(s?) '}' {$item[2]}
-	       | <skip: $withoutnewline> '[' <skip: $withnewline> section(s?) ']' {$item[2]}
-xml_1 : xml_single 
-      | xml_full section(s?) "</" "$arg[0]" ">" 
-          {
-	   unshift (@{$item[2]},$item[1]); 
-	   #else {unshift(@{$item[2]},[$item[1]]);}
-	   array2hash($item[2],$thisparser);
-	  }
-#I know it seems redundant, but it's because there's a flaw in the parser: 
-# if it succeeds in a production, but it succeeds in the wrong path, it won't try again down a different one.
-#  This is a workaround.
-xml_single: varlist "/>" {$item[1]} | xml_assigns "/>" {$item[1]} | "/>" {[]}
-#This thing requires arrays.
-xml_full: varlist ">" {
-	 #if(ref($item[1])=~/ARRAY/) {
-          ["attribs",$item[1]];
-	  #for my $it (@{$item[1]})
-	  # { push(@return,$it); };
-	  # \@return;
-	#  }
-	 #else {["attribs",$item[1]]; };
-	} 
-        | xml_assigns ">"  { ["attribs",$item[1]];} 
-	| ">"  {[]}
-
-assigns: assign(s?) {array2hash($item[1],$thisparser)}
-
-xml_assigns: xml_assign(s?) {array2hash($item[1])}
-xml_assign: left <skip: $withoutnewline> svar { [$item[1],$item[3]] }
-
-ini_name: /\[([^\n#]*)\]/  {$1}
-
-#The difference between normal and xml is that xml only has single variables on the right side, and 
-#there's no space separated
-
-
-#The tokens are sacred unless quotes are used.
-#If the first match failed, it means that we failed to find any assignment operator.  
-#  If this is the case, we will assume it is without the operator.
-#  Note that it the right is allowed to return an empty array/singleton by design.
-assign:  left <skip: $withoutnewline> right {[$item[1],$item[3]]}
-      | <skip: $withoutnewline >svar {[$item[2]]}
-
-csvlist: csv(s) <skip: $withoutnewline > /([^\n#]*?)\n/
-          { [@{$item[1]},$1]; }
-csv: svar ',' {$item[1]} 
-   | /([^\n#;]*?),/ {$1;}
-tsv: /([^\n#]*?)\t/ {$1;}
-#There should be only one variable on the left.  If more than one are quoted, then it means that there are more than one on the left.
-left:  svar /(=>|:=|:|=)/ {$item[1]}
-    |  /([^\{\}<>\(\)\[\]\n#]+?)((?:=>|:|=)=?)/ {$1;}
-    |  csv 
-    |  svar 
-
-right: csvlist  {$item[1]} | 
-       varlist  {$item[1]}
-
-#This is for ini files.  Each variable list must end at the end of a line.  This is to keep them
-#From being confused with other types of files.
-strict_assign:   left <skip: $withoutnewline> strict_right {[$item[1],$item[3]]}
-      | <skip: $withoutnewline >svar "\n" {[$item[2]]}
-strict_right: csvlist "\n" {$item[1]} | 
-              varlist "\n" {$item[1]}
-
-#This is supposed to be a flat list.  If it isn't, you're doing something wrong.  Stop it.
-varlist: svar(s) 
-{
-if(@{$item[1]}==1) { $item[1]->[0] ; }
-else {$item[1]};
-#print (@item);
-#if(scalar($item[2]) && scalar(@{$item[2]->[0]})) { unshift(@{$item[2]->[0]},$item[1]);  $item[2]->[0];}
-#else {$item[1];};
-}
-#       | varname 
-#         {
-	 #This part is now deprecated.  More sophisticated variable matching now.
-#	  my @return=split(/\s+/,$item[1]);
-#          if($#return==0) { $return[0]; } else {\@return; };
-#         }
-
-};
 #$::RD_HINT=1;
 $::RD_AUTOACTION =  q{ ($#item>1)?[@item[1..$#item]]:$item[1]};
 #  $::RD_TRACE=1;
   $dat{'filename'} = $_[1] if(scalar(@_)>1);
-#  $dat{'parser'}=new Parse::RecDescent($poop);
   $dat{'parser'}=Config::Magic::Grammar->new();
 #  $dat{parser}->{skip}=qr{((\/[*].*?[*]\/)|((#|;|\/\/).*?\n)|\s)*}sm;
   $dat{'parser'}->{'ordered'} = 0;
   $dat{'parser'}->{'ordered'} = $_[2] if(scalar(@_)>2);
-  bless $dat{'parser'}, "Parse::RecDescent";
+#  bless $dat{'parser'}, "Parse::RecDescent";
   bless(\%dat);
   return \%dat;
 }
+
 1;
 __END__
 =head1 NAME
